<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// C
	'compresseur_description' => 'Compresión de css y javascript en los encabezados de las páginas HTML de <code>ecrire/</code> y/o del sitio público',
	'compresseur_slogan' => 'Compresión de css y javascript ',
];
